=========
Changelog
=========

Version v0.0.5
==============

- new structure for 'naming_conventions' (implemented: SGRT, EODR)
- more options for en/decoding of filename fields.
- includes now file search and volume determination

Version v0.0.2
==============

- Switch to PyScaffold v2.5.11

Version v0.0.1
==============

- Add class SmartPath, SmartTree and SmartFilename
- Add class SgrtFilename and function sgrt_path
- Add unit tests
